models
==================================================
**Module**: :mod:`espressodb.base.models`

.. currentmodule:: espressodb.base.models

.. autosummary::
   Base.get_or_create_from_parameters
   Base.save
   Base.check_consistency
   Base.specialization

------

.. automodule:: espressodb.base.models
    :members:
    :special-members:
